sqlobject.inheritance.tests.test\_indexes module
================================================

.. automodule:: sqlobject.inheritance.tests.test_indexes
    :members:
    :undoc-members:
    :show-inheritance:
